<!-- 
    Security Knowledge Framework is an expert system application 
    that uses OWASP Application Security Verification Standard, code examples,
    helps developers in pre-development and post-development.  
    Copyright (C) 2015  Glenn ten Cate, Riccardo ten Cate

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.
-->

 {% include 'header.html' %}

 <!-- **********************************************************************************************************************************************************
      MAIN CONTENT
      *********************************************************************************************************************************************************** -->
      <!--main content start-->
      <section id="main-content">
          <section class="wrapper">
          	<h3>-<i class="fa fa-angle-right"></i><a href='/project'>Projects</a> -> <a href='/project-list'> Getting started</a> -> Security checklists</h3>
		  		<div class="row mt">
			  		<div class="col-lg-12">
            <div class="alert alert-info">
            <b>Note:</b>
            Whenever you upload a new checklist and this one already exists for this project, the old version will be overwritten. 
            </div>
          
						<div class="content-panel">
               <table class="table table-striped table-advance table-hover"> 
                  <thead>
                  <tr>
                      <th><i class="fa fa-bullhorn"></i> Checklist</th>
                      <th class="hidden-phone"><i class="fa fa-question-circle"></i> Description</th>
                      <th><i class="fa fa-bookmark"></i> Level</th>
                      <th></th>
                      <th><i class=" fa fa-edit"></i> Take list</th>
                  </tr>
                  </thead>
                  <tbody>
                    <tr>
                      <td><a href="#"></a>Certified secure basic</td>
                      <td class="hidden-phone">The basic web application audit checklist, latest version available at : www.certifiedsecure.com/checklists.</td>
                      <td class="hidden-phone">Custom</td>
                      <td></td>
                      <td>                
                      <!-- MODALS -->
      				          <div class="showbak">
      						      <!-- Button trigger modal -->
					         	  <button class="btn btn-success btn-xs" data-toggle="modal" data-target="#myModal1">
						           Start                     
					              </button>
						 
						          <!-- Modal -->
						          <div class="modal fade" id="myModal1" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
						          <div class="modal-dialog">
						          <div class="modal-content">
						          <div class="modal-header">
						          <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
						          <h4 class="modal-title" id="myModalLabel">Certified secure basic audit</h4>
						          </div>
						          <div   class="modal-body">
						          <table id='checklist' style="width:525px">
						          <form method='post' action='/project-checklist-add'/>
						          
                    {% set counter_basic = 0 -%}
                    {% set count_cs_basic = 0 -%}
                    {% for entry in basic_content -%}
           
                    <tr>


                      {% if basic_kb_ids[counter_basic] == '0' -%}
                        <td style='font-size:0.87em; padding-top:9px; border-style:solid; border-color:black; border-width:0px;'> 
                        <b style="p { font-weight:bold; }">{{entry|safe}}</b>
                      {% else %}
                         <td style='font-size:0.8em; border-style:solid; border-color:black; border-width:1px;'> 
                        {{entry|safe}}
                      {% endif %}
                      </td>
                      <td></td>
                        {% if basic_kb_ids[counter_basic] != '0' -%}
                        {% set count_cs_basic = count_cs_basic + 1 %}
						 <td style='font-size:0.8em; border-style:solid; border-color:black; border-width:1px; text-align:center;'>
                        <select name='answer{{count_cs_basic|safe}}' >
                        <option value='yes' >Done</option>
                        <option value='no' >Not done</option>
                        <option value='yes' >N.A.</option>
                        </select>
                        </td>
                        <input type='hidden' name='vulnID{{count_cs_basic|safe}}' value='{{basic_kb_ids[counter_basic]|safe}}'/>
                        <input type='hidden' name='questionID{{count_cs_basic|safe}}' value='{{basic_ids[counter_basic]|safe}}'/>
                        <input type='hidden' name='listID{{count_cs_basic|safe}}' value='{{basic_list|safe}}'/>  
                        {% endif %}
                        </td> 
                    </tr>
                    {% set counter_basic = counter_basic + 1 %}
                    {% endfor %}
                      <input type='hidden' name='projectID' value='{{project_id|safe}}'/>
                      <input type='hidden' name='projectName' value='{{projectName|safe}}'/>
                      <input type="hidden" name="csrf_token" value="{{csrf_token|safe}}" id="csrf_token">
    								  </table>
    						          </div>
    						          <div class="modal-footer">
    						          <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
    						          <input type="submit" name="submit" class="btn btn-primary" value='Save checklist'/>
    						          </form>
    						          </div>
    						          </div>
    						  		  </div>
    								  </div>      				
          							  </div><!-- /showback -->
                        <tr>
                          <td><a href="basic_table.html#"></a>Certified secure advanced</td>
                          <td class="hidden-phone">The advanced web application audit checklist, latest version available at : www.certifiedsecure.com/checklists.</td>
                          <td class="hidden-phone">Custom</td>
                          <td></td>
                          <td>      
                            <!-- MODALS -->
      				              <div class="showbak">
      						      <!-- Button trigger modal -->
					         	  <button class="btn btn-success btn-xs" data-toggle="modal" data-target="#myModal2">
						           Start                     
					              </button>
						
						          <!-- Modal -->
						          <div class="modal fade" id="myModal2" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
						          <div class="modal-dialog">
						          <div class="modal-content">
						          <div class="modal-header">
						          <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
						          <h4 class="modal-title" id="myModalLabel">Certified secure advanced audit</h4>
						          </div>
						          <div   class="modal-body">
						          <table id='checklist' style="width:525px">
						          <form method='post' action='/project-checklist-add'/>
						          
                      {% set counter_advanced = 0 -%}
                      {% set count_cs_adv = 0 -%}
                      {% for entry in advanced_content -%}
                       
                      <tr>
                      {% if advanced_kb_ids[counter_advanced] == '0' -%}
                     <td style='font-size:0.87em; padding-top:9px; border-style:solid; border-color:black; border-width:0px;'> 
                        <b style="p { font-weight:bold; }">{{entry|safe}}</b>
                      {% else %}
                          <td style='font-size:0.8em; border-style:solid; border-color:black; border-width:1px;'> 
                        {{entry|safe}}
                      {% endif %}

                      </td>
                        <td></td>
                          {% if advanced_kb_ids[counter_advanced] != '0' -%}
                          {% set count_cs_adv = count_cs_adv + 1 %}
  						  <td style='font-size:0.8em; border-style:solid; border-color:black; border-width:1px; text-align:center;'>
                          <select name='answer{{count_cs_adv|safe}}' >
                          <option value='yes' >Done</option>
                          <option value='no' >Not done</option>
                          <option value='yes' >N.A.</option>
                          </select>
                          </td>
                          <input type='hidden' name='vulnID{{count_cs_adv|safe}}' value='{{advanced_kb_ids[counter_advanced]|safe}}'/>
                          <input type='hidden' name='questionID{{count_cs_adv|safe}}' value='{{advanced_ids[counter_advanced]}}'/>
                          <input type='hidden' name='listID{{count_cs_adv|safe}}' value='{{advanced_list|safe}}'>
                          {% endif %}
                          </td>
                      </tr>

                      {% set counter_advanced = counter_advanced + 1 %}
                      {% endfor %}
                      <input type='hidden' name='projectID' value='{{project_id|safe}}'/>
                      <input type='hidden' name='projectName' value='{{projectName|safe}}'/>
                      <input type="hidden" name="csrf_token" value="{{csrf_token|safe}}" id="csrf_token">
      								  </table>
      						          </div>
      						          <div class="modal-footer">
      						          <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
      						          <input type="submit" name="submit" class="btn btn-primary" value='Save checklist'/>
      						          </form>
      						          </div>
      						          </div>
      						  		  </div>
      								  </div>      				
            							  </div><!-- /showback -->
                                   
                                   
                             <tr>
                              <td><a href="#"></a>OWASP top 10</td>

                              <td class="hidden-phone">Top 10 vulnerabilities composed by OWASP.</td>
                              <td class="hidden-phone">Technical debt</td>
                              <td></td>
                              <td>          
                            <!-- MODALS -->
      				              <div class="showbak">
      						      <!-- Button trigger modal -->
					         	  <button class="btn btn-success btn-xs" data-toggle="modal" data-target="#myModal3">
						           Start                     
					              </button>
						
						          <!-- Modal -->
						          <div class="modal fade" id="myModal3" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
						          <div class="modal-dialog">
						          <div class="modal-content">
						          <div class="modal-header">
						          <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
						          <h4 class="modal-title" id="myModalLabel">Owasp top 10</h4>
						          </div>
						          <div   class="modal-body">
						          <table id='checklist' style="width:525px">
						          <form method='post' action='/project-checklist-add'/>

                      {% set counter_owasp = 0 -%}
                      {% set count_owasp_top = 0 -%}
                      {% for entry in owasp_content -%}


                      <tr>

                        {% if owasp_kb_ids[counter_owasp] == '0' -%}
                         <td style='font-size:0.87em; padding-top:9px; border-style:solid; border-color:black; border-width:0px;'> 
                        <b style="p { font-weight:bold; }">{{entry|safe}}</b>
                      {% else %}
                        <td style='font-size:0.8em; border-style:solid; border-color:black; border-width:1px;'> 
                        {{entry|safe}}
                      {% endif %}
                      </td>
                        <td></td>

                            {% if owasp_kb_ids[counter_owasp] != '0' -%}
                            {% set count_owasp_top = count_owasp_top + 1 %}
                         <td style='font-size:0.8em; border-style:solid; border-color:black; border-width:1px; text-align:center;'>
                          <select name='answer{{count_owasp_top|safe}}'>
                          <option value='yes' >Yes</option>
                          <option value='no' >No</option>
                          <option value='yes' >N.A.</option>
                          </select>
                          </td>
                          <input type='hidden' name='vulnID{{count_owasp_top|safe}}' value='{{owasp_kb_ids[counter_owasp]|safe}}'/>
                          <input type='hidden' name='questionID{{count_owasp_top|safe}}' value='{{owasp_ids[counter_owasp]|safe}}'/>
                          <input type='hidden' name='listID{{count_owasp_top|safe}}' value='{{owasp_list|safe}}'>
                          {% endif %}
                          </td>
                      </tr>
                      {% set counter_owasp = counter_owasp + 1 %}
                      {% endfor %}
                      <input type='hidden' name='projectID' value='{{project_id|safe}}'/>
                      <input type='hidden' name='projectName' value='{{projectName|safe}}'/>
                      <input type="hidden" name="csrf_token" value="{{csrf_token|safe}}" id="csrf_token">
								  </table>
						          </div>
						          <div class="modal-footer">
						          <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
						          <input type="submit" name="submit" class="btn btn-primary" value='Save checklist'/>
						          </form>
						          </div>
						          </div>
						  		  </div>
								  </div>      				
      							  </div>

      
                             <tr>
                              <td><a href="#"></a>OWASP ASVS Level 1</td>

                              <td class="hidden-phone">OWASP Application Security Verification Standard Level 1.</td>
                              <td class="hidden-phone">Recommended</td>
                              <td></td>
                              <td>          
                            <!-- MODALS -->
                            <div class="showbak">
                        <!-- Button trigger modal -->
                      <button class="btn btn-success btn-xs" data-toggle="modal" data-target="#myModal7">
                       Start                     
                        </button>
            
                      <!-- Modal -->
                      <div class="modal fade" id="myModal7" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
                      <div class="modal-dialog">
                      <div class="modal-content">
                      <div class="modal-header">
                      <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
                      <h4 class="modal-title" id="myModalLabel">OWASP ASVS Level 1</h4>
                      </div>
                      <div   class="modal-body">
                      <table id='checklist' style="width:525px">
                      <form method='post' action='/project-checklist-add'/>

                      {% set counter_owasp_lvl1 = 0 -%}
                      {% set count_asvs_1 = 0 -%}
                      {% for entry in owasp_content_lvl1 -%}

                      <tr>
                      {% if owasp_kb_ids_lvl1[counter_owasp_lvl1] == '0' -%}
                        <td style='font-size:0.87em; padding-top:9px; border-style:solid; border-color:black; border-width:0px;'> 
                        <b style="p { font-weight:bold; }">{{entry|safe}}</b>
                      {% else %}
                         <td style='font-size:0.8em; border-style:solid; border-color:black; border-width:1px;'>
                        {{entry|safe}}
                      {% endif %}
                      </td>
                        <td></td>
                          {% if owasp_kb_ids_lvl1[counter_owasp_lvl1] != '0' -%}
                          {% set count_asvs_1 = count_asvs_1 + 1 %}
                          <td style='font-size:0.8em; border-style:solid; border-color:black; border-width:1px; text-align:center;'>
                          <select name='answer{{count_asvs_1|safe}}'>
                          <option value='yes' >Yes</option>
                          <option value='no' >No</option>
                          <option value='yes' >N.A.</option>
                          </select>
                          </td>
                          <input type='hidden' name='vulnID{{count_asvs_1|safe}}' value='{{owasp_kb_ids_lvl1[counter_owasp_lvl1]|safe}}'/>
                          <input type='hidden' name='questionID{{count_asvs_1|safe}}' value='{{owasp_ids_lvl1[counter_owasp_lvl1]|safe}}'/>
                          <input type='hidden' name='listID{{count_asvs_1|safe}}' value='{{owasp_list_lvl1|safe}}'>
                          {% endif %}
                          </td>
                      </tr>
                      {% set counter_owasp_lvl1 = counter_owasp_lvl1 + 1 %}
                      {% endfor %}
                      <input type='hidden' name='projectID' value='{{project_id|safe}}'/>
                      <input type='hidden' name='projectName' value='{{projectName|safe}}'/>
                      <input type="hidden" name="csrf_token" value="{{csrf_token|safe}}" id="csrf_token">
                  </table>
                      </div>
                      <div class="modal-footer">
                      <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                      <input type="submit" name="submit" class="btn btn-primary" value='Save checklist'/>
                      </form>
                      </div>
                      </div>
                    </div>
                  </div>              
                      </div>

                             <tr>
                              <td><a href="#"></a>OWASP ASVS Level 2</td>

                              <td class="hidden-phone">OWASP Application Security Verification Standard Level 2.</td>
                              <td class="hidden-phone">Recommended</td>
                              <td></td>
                              <td>          
                            <!-- MODALS -->
                            <div class="showbak">
                        <!-- Button trigger modal -->
                      <button class="btn btn-success btn-xs" data-toggle="modal" data-target="#myModal8">
                       Start                     
                        </button>
            
                      <!-- Modal -->
                      <div class="modal fade" id="myModal8" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
                      <div class="modal-dialog">
                      <div class="modal-content">
                      <div class="modal-header">
                      <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
                      <h4 class="modal-title" id="myModalLabel">OWASP ASVS Level 2</h4>
                      </div>
                      <div   class="modal-body">
                      <table id='checklist' style="width:525px">
                      <form method='post' action='/project-checklist-add'/>

                      {% set counter_owasp_lvl2 = 0 -%}
                      {% set count_asvs_2 = 0 -%}
                      {% for entry in owasp_content_lvl2 -%}


                      <tr>
                      {% if owasp_kb_ids_lvl2[counter_owasp_lvl2] == '0' -%}
                        <td style='font-size:0.87em; padding-top:9px; border-style:solid; border-color:black; border-width:0px;'> 
                        <b style="p { font-weight:bold; }">{{entry|safe}}</b>
                      {% else %}
                        <td style='font-size:0.8em; border-style:solid; border-color:black; border-width:1px;'> 
                        {{entry|safe}}
                      {% endif %}
                      </td>
                        <td></td>
                          {% if owasp_kb_ids_lvl2[counter_owasp_lvl2] != '0' -%}
                          {% set count_asvs_2 = count_asvs_2 + 1 %}
                          <td style='font-size:0.8em; border-style:solid; border-color:black; border-width:1px; text-align:center;'>
                          <select name='answer{{count_asvs_2|safe}}'>
                          <option value='yes' >Yes</option>
                          <option value='no' >No</option>
                          <option value='yes' >N.A.</option>
                          </select>
                          </td>
                          <input type='hidden' name='vulnID{{count_asvs_2|safe}}' value='{{owasp_kb_ids_lvl2[counter_owasp_lvl2]|safe}}'/>
                          <input type='hidden' name='questionID{{count_asvs_2|safe}}' value='{{owasp_ids_lvl2[counter_owasp_lvl2]|safe}}'/>
                          <input type='hidden' name='listID{{count_asvs_2|safe}}' value='{{owasp_list_lvl2|safe}}'>
                          {% endif %}
                          </td>
                      </tr>
                      {% set counter_owasp_lvl2 = counter_owasp_lvl2 + 1 %}
                      {% endfor %}
                      <input type='hidden' name='projectID' value='{{project_id|safe}}'/>
                      <input type='hidden' name='projectName' value='{{projectName|safe}}'/>
                      <input type="hidden" name="csrf_token" value="{{csrf_token|safe}}" id="csrf_token">
                  </table>
                      </div>
                      <div class="modal-footer">
                      <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                      <input type="submit" name="submit" class="btn btn-primary" value='Save checklist'/>
                      </form>
                      </div>
                      </div>
                    </div>
                  </div>              
                      </div>

                             <tr>
                              <td><a href="#"></a>OWASP ASVS Level 3</td>

                              <td class="hidden-phone">OWASP Application Security Verification Standard Level 3.</td>
                              <td class="hidden-phone">Advanced</td>
                              <td></td>
                              <td>          
                            <!-- MODALS -->
                            <div class="showbak">
                        <!-- Button trigger modal -->
                      <button class="btn btn-success btn-xs" data-toggle="modal" data-target="#myModal9">
                       Start                     
                        </button>
            
                      <!-- Modal -->
                      <div class="modal fade" id="myModal9" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
                      <div class="modal-dialog">
                      <div class="modal-content">
                      <div class="modal-header">
                      <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
                      <h4 class="modal-title" id="myModalLabel">OWASP ASVS Level 3</h4>
                      </div>
                      <div   class="modal-body">
                      <table id='checklist' style="width:525px">
                      <form method='post' action='/project-checklist-add'/>

                      {% set counter_owasp_lvl3 = 0 -%}
                      {% set count_asvs_3 = 0 -%}
                      {% for entry in owasp_content_lvl3 -%}


                      <tr>
                       {% if owasp_kb_ids_lvl3[counter_owasp_lvl3] == '0' -%}
                       <td style='font-size:0.87em; padding-top:9px; border-style:solid; border-color:black; border-width:0px;'> 
                        <b style="p { font-weight:bold; }">{{entry|safe}}</b>
                      {% else %}
                        <td style='font-size:0.8em; border-style:solid; border-color:black; border-width:1px;'> 
                        {{entry|safe}}
                      {% endif %}
                      </td>
                        <td></td>
                          {% if owasp_kb_ids_lvl3[counter_owasp_lvl3] != '0' -%}
                           {% set count_asvs_3 = count_asvs_3 + 1 %}
                           <td style='font-size:0.8em; border-style:solid; border-color:black; border-width:1px; text-align:center;'>
                          <select name='answer{{count_asvs_3|safe}}'>
                          <option value='yes' >Yes</option>
                          <option value='no' >No</option>
                          <option value='yes' >N.A.</option>
                          </select>
                          </td>
                          <input type='hidden' name='vulnID{{count_asvs_3|safe}}' value='{{owasp_kb_ids_lvl3[counter_owasp_lvl3]|safe}}'/>
                          <input type='hidden' name='questionID{{count_asvs_3|safe}}' value='{{owasp_ids_lvl3[counter_owasp_lvl3]|safe}}'/>
                          <input type='hidden' name='listID{{count_asvs_3|safe}}' value='{{owasp_list_lvl3|safe}}'>
                          {% endif %}
                          </td>
                      </tr>
                      {% set counter_owasp_lvl3 = counter_owasp_lvl3 + 1 %}
                      {% endfor %}
                      <input type='hidden' name='projectID' value='{{project_id|safe}}'/>
                      <input type='hidden' name='projectName' value='{{projectName|safe}}'/>
                      <input type="hidden" name="csrf_token" value="{{csrf_token|safe}}" id="csrf_token">
                  </table>
                      </div>
                      <div class="modal-footer">
                      <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                      <input type="submit" name="submit" class="btn btn-primary" value='Save checklist'/>
                      </form>
                      </div>
                      </div>
                    </div>
                  </div>              
                      </div>

                    <tr>
                    <td><a href="#"></a>Custom Checklist</td>
                    <td class="hidden-phone">This checklist is a template for your own custom checklist. If you have created one please create a Pull request on GIT.</td>
                    <td class="hidden-phone">Custom</td>
                    <td></td>
                    <td>
                        
                        
                                      <!-- MODALS -->
                            <div class="showbak">
                        <!-- Button trigger modal -->
                      <button class="btn btn-success btn-xs" data-toggle="modal" data-target="#myModal4">
                       Start                     
                        </button>
            
                      <!-- Modal -->
                      <div class="modal fade" id="myModal4" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
                      <div class="modal-dialog">
                      <div class="modal-content">
                      <div class="modal-header">
                      <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
                      <h4 class="modal-title" id="myModalLabel">Certified secure advanced audit</h4>
                      </div>
                      <div   class="modal-body">
                      <table id='checklist' style="width:525px">
                      <form method='post' action='/project-checklist-add'/>
                      
                  {% set counter_custom = 0 -%}
                  {% set count_custom = 0 -%}
                  {% for entry in custom_content -%}

                  <tr>
                     {% if custom_kb_ids[counter_custom] == '0' -%}
                       <td style='font-size:0.87em; padding-top:9px; border-style:solid; border-color:black; border-width:0px;'> 
                        <b style="p { font-weight:bold; }">{{entry|safe}}</b>
                      {% else %}
                        <td style='font-size:0.8em; border-style:solid; border-color:black; border-width:1px;'> 
                        {{entry|safe}}
                      {% endif %}
                    </td>
                    <td></td>
                      {% if custom_kb_ids[counter_custom] != '0' -%}
                      {% set count_custom = count_custom + 1 %}
                     <td style='font-size:0.8em; border-style:solid; border-color:black; border-width:1px; text-align:center;'>
                      <select name='answer{{count_custom|safe}}' >
                      <option value='yes' >Done</option>
                      <option value='no' >Not done</option>
                      <option value='yes' >N.A.</option>
                      </select>
                      </td>
                      <input type='hidden' name='vulnID{{count_custom|safe}}' value='{{custom_kb_ids[counter_custom]|safe}}'>
                      <input type='hidden' name='questionID{{count_custom|safe}}' value='{{custom_ids[counter_custom]|safe}}'>
                      <input type='hidden' name='listID{{count_custom|safe}}' value='{{custom_list|safe}}'>
                       {% endif %}
                      </td>
                  </tr>

                  {% set counter_custom = counter_custom + 1 %}
                  {% endfor %}
                      <input type='hidden' name='projectID' value='{{project_id|safe}}'/>
                      <input type='hidden' name='projectName' value='{{projectName|safe}}'/>
                      <input type="hidden" name="csrf_token" value="{{csrf_token|safe}}" id="csrf_token">
                  </table>
                      </div>
                      <div class="modal-footer">
                      <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                      <input type="submit" name="submit" class="btn btn-primary" value='Save checklist'/>
                      </form>
                      </div>
                      </div>
                    </div>
                  </div>              
                      </div><!-- /showback -->
                  
                              
                              </tbody>
                          </table>

                      </div>
	
               </div><!-- /col-lg-4 -->			
		  	</div><!-- /row -->
		</section><!--/wrapper -->
      </section><!-- /MAIN CONTENT -->
         

 {% include 'footer.html' %}
 
